import fedmsg
import fedmsg.encoding
import fedmsg.consumers

from . import triggers, utils, config


class BodhiJobTrigger(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.prod.bodhi.update.request.*"
    jsonify = False
    config_key = 'taskotron.bodhijobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(BodhiJobTrigger, self).__init__(*args, **kw)
        self.trigger = triggers.get_trigger(config.trigger_type)

    def consume(self, message):
        usable_message = fedmsg.encoding.loads(message.body)

        topic = usable_message['topic']
        builds = usable_message['msg']['update']['builds']
        nvrs = [build['nvr'] for build in builds]

        # we want only requests to stable and testing
        if not topic.endswith('stable') and not topic.endswith('testing'):
            return

        # do not schledule jobs for blacklisted releases
        if nvrs[0].endswith(tuple(config.blacklist_releases)):
            return

        updatetitle = usable_message['msg']['update']['title']
        dist_tag = usable_message['msg']['update']['release']['dist_tag']

        koji_tag = '%s-updates' % dist_tag
        if topic.endswith('testing'):
            koji_tag += '-testing'

        arches = utils.get_arches(nvr=nvrs[0])

        tasks = []
        tasks += [(updatetitle, 'bodhi_id', task) for task in config.bodhi_tasks]
        tasks += [(koji_tag, 'koji_tag', task) for task in config.bodhi_to_koji_tag_tasks]

        for (item, item_type, task) in tasks:
            for arch in arches:
                self.log.info('triggering %s for %s on %s', task, item, arch)

                if config.job_logging:
                    try:
                        utils.log_job(config.joblog_file, item, item_type, task, arch)
                    except IOError, e:
                        self.log.warning('Cannot log a job into %s', config.joblog_file)

                output = self.trigger.trigger_job(item, item_type, task, arch)
                for line in output:
                    self.log.info(line)
