import fedmsg
import fedmsg.encoding
import fedmsg.consumers

from . import triggers, utils, config


ITEM_TYPE = 'koji_build'

class KojiJobTrigger(fedmsg.consumers.FedmsgConsumer):
    topic = "org.fedoraproject.prod.buildsys.tag"
    jsonify = False
    config_key = 'taskotron.kojijobtrigger.enabled'

    def __init__(self, *args, **kw):
        super(KojiJobTrigger, self).__init__(*args, **kw)
        self.trigger = triggers.get_trigger(config.trigger_type)

    def consume(self, message):
        usable_message = fedmsg.encoding.loads(message.body)

        tag = usable_message['msg']['tag']
        release = usable_message['msg']['release']

        # we look only for pending builds
        if not tag.endswith('pending'):
            return

        # do not schledule jobs for blacklisted releases
        if release.endswith(tuple(config.blacklist_releases)):
            return

        name = usable_message['msg']['name']
        version = usable_message['msg']['version']
        buildid = usable_message['msg']['build_id']

        envr = "%s-%s-%s" % (name, version, release)

        arches = utils.get_arches(buildid=buildid)

        for task in config.koji_tasks:
            for arch in arches:
                self.log.info('triggering %s for %s on %s', task, envr, arch)

                if config.job_logging:
                    try:
                        utils.log_job(config.joblog_file, envr, ITEM_TYPE, task, arch)
                    except IOError, e:
                        self.log.warning('Cannot log a job into %s', config.joblog_file)

                output = self.trigger.trigger_job(envr, ITEM_TYPE, task, arch)
                for line in output:
                    self.log.info(line)
