import requests

from . import config

class BaseTrigger(object):
    """
    Format:
    {
        'item': <name of item - envr, update id, koji tag, etc.>,
        'item_type': <koji_build, koji_tag, bodhi_id>,
        'taskname': <task to be scheduled>,
        'arch': <arch needed for execution, x86_64, i386 etc.>
    }
    """
    def trigger_job(self, item, item_type, taskname, arch):
        raise NotImplementedError


class StreamTrigger(BaseTrigger):
    def trigger_job(self, item, item_type, taskname, arch):
        output = ["StreamTrigger received:",
                    "item: %s" % item,
                    "item_type: %s" % item_type,
                    "taskname: %s" % taskname,
                    "arch: %s" % arch]

        yield '\n'.join(output)


class BuildbotTrigger(BaseTrigger):
    def trigger_job(self, item, item_type, taskname, arch):
        output = ["Buildbot received:",
                    "item: %s" % item,
                    "item_type: %s" % item_type,
                    "taskname: %s" % taskname,
                    "arch: %s" % arch]

        yield '\n'.join(output)

        s = requests.session()

        r = s.post('%s/login' % config.buildbot_url,
               data={'username': config.buildbot_username,
                     'passwd': config.buildbot_password})

        yield "Login request status: %s" % str(r.status_code)

        if arch not in ['i386', 'x86_64']:
            builder = 'all'
        else:
            builder = arch

        r = s.post('%s/builders/%s/force' % (config.buildbot_url, builder),
               data={'forcescheduler': 'rpmcheck',
                     'reason': 'triggered by fedmsg',
                     'item': item,
                     'item_type': item_type,
                     'taskname': taskname,
                     'arch': arch})

        yield "Force request ('%s/builders/%s/force') status: %s" % (config.buildbot_url, builder, str(r.status_code))

        r = s.get('%s/logout' % config.buildbot_url)

        yield "Logout request status: %s" % str(r.status_code)


_triggers = {'StreamTrigger': StreamTrigger, 'BuildbotTrigger': BuildbotTrigger}

def get_trigger(trigger_type):
    return _triggers[trigger_type]()
