import pytest
from dingus import Dingus
from bunch import Bunch

from jobtriggers import koji_msg


@pytest.mark.usefixtures('prepare')
class TestKojiJobTrigger():
    @pytest.fixture
    def prepare(self, monkeypatch):
        self.ref_name = 'stage'
        self.ref_version = '4.1.1'
        self.ref_release = '3.fc18'
        self.ref_nvr = '%s-%s-%s' % (self.ref_name, self.ref_version, self.ref_release)
        self.ref_tag = 'f18-updates-testing-pending'

        self._create_msg(self.ref_name, self.ref_release, self.ref_tag, self.ref_version)

        self.ref_tasks = ['koji_task1', 'koji_task2']
        self.ref_validarches = ['i386', 'x86_64']
        self.ref_blacklist_releases= ['el5', 'el6']

        stub_hub = Bunch(config=Bunch(get=0))

        self.helper = koji_msg.KojiJobTrigger(stub_hub)
        self.helper.trigger = Dingus()

        monkeypatch.setattr(koji_msg.utils, 'get_arches', lambda *a, **k: self.ref_validarches)

        koji_msg.config.koji_tasks = self.ref_tasks
        koji_msg.config.valid_arches = self.ref_validarches
        koji_msg.config.blacklist_releases = self.ref_blacklist_releases
        koji_msg.config.job_logging = False

    def _create_msg(self, ref_name, ref_release, ref_tag, ref_version):
        self.ref_message = Bunch(body='{"i": 1,\
                                        "msg": {"build_id": 221146,\
                                                "name": "%s",\
                                                "owner": "ralph",\
                                                "release": "%s",\
                                                "tag": "%s",\
                                                "tag_id": 216,\
                                                "user": "bodhi",\
                                                "version": "%s"},\
                                        "timestamp": 1359603469.21164,\
                                        "topic": "org.fedoraproject.prod.buildsys.tag",\
                                        "username": "apache"}' %
                                        (ref_name, ref_release, ref_tag, ref_version))

    def test_consume(self):
        self.helper.consume(self.ref_message)

        trigger_calls = self.helper.trigger.trigger_job.calls()

        assert len(trigger_calls) == 4

        assert trigger_calls[0][1] == (self.ref_nvr, koji_msg.ITEM_TYPE, self.ref_tasks[0], self.ref_validarches[0])
        assert trigger_calls[1][1] == (self.ref_nvr, koji_msg.ITEM_TYPE, self.ref_tasks[0], self.ref_validarches[1])
        assert trigger_calls[2][1] == (self.ref_nvr, koji_msg.ITEM_TYPE, self.ref_tasks[1], self.ref_validarches[0])
        assert trigger_calls[3][1] == (self.ref_nvr, koji_msg.ITEM_TYPE, self.ref_tasks[1], self.ref_validarches[1])

    def test_consume_notwatched_tag(self):
        ref_tag = 'f18-randomtag'
        self._create_msg(self.ref_name, self.ref_release, ref_tag, self.ref_version)

        self.helper.consume(self.ref_message)

        trigger_calls = self.helper.trigger.trigger_job.calls()

        assert trigger_calls == []

    def test_consume_blacklisted_release(self):
        ref_release = '3.el5'
        self._create_msg(self.ref_name, ref_release, self.ref_tag, self.ref_version)

        self.helper.consume(self.ref_message)

        trigger_calls = self.helper.trigger.trigger_job.calls()

        assert trigger_calls == []
